@@ -33,10 +33,16 @@ VERSION = "@VER@"
 
 import gtk
 
-import os
+import os, shutil
 import datetime
 from datetime import date
 import time
+from textwrap import dedent
+import ConfigParser
+
+# TODO check for needed modules
+from databases import DATABASES
+import databases
 
 # parse locales from python module
 # Do you say "1. January" or "January 1."?
@@ -55,34 +61,56 @@ try:
 except ImportError:
     _ = lambda x: x
 
-
 CURRENT_DAY = time.strftime("%d", time.localtime(time.time()))
 
-
 class Conf:
     '''Class for handle all configurations.'''
 
     def __init__(self):
         '''Try to read config file or initialize with default values.'''
-        import ConfigParser
-        from .databases import MySQL
         self.firstday = self.lastday = None
         self.notify_future_bdays = None
         self.used_databases = None
         self.csv_files = None
-        self.mysql = MySQL()
+        self.mysql = databases.mysql_db
         self.settings = ConfigParser.ConfigParser()
-        try:
-            self.settings.readfp(file(os.environ['HOME'] + "/.gbirthdayrc"))
-        except IOError:
-            self.settings.add_section("main")
-            self.default_values()
+
+        # If XDG_CONFIG_HOME is defined, use it to store config files
+        if 'XDG_CONFIG_HOME' in os.environ:
+            self.base_config_path = os.environ['XDG_CONFIG_HOME'] + "/gbirthday"
+            # If no config file here, check for config files in ~/.config
+            if not os.path.isdir(self.base_config_path):
+                if os.path.isdir(os.environ['HOME'] + "/.config/gbirthday"):
+                    shutil.copytree(os.environ['HOME'] + "/.config/gbirthday",
+                                    self.base_config_path)
+                else:
+                    os.makedirs(self.base_config_path)
+        # else, use ~/.config
         else:
-            if self.settings.has_section("main"):
-                self.sync_to_mem()
-            else:
-                self.settings.add_section("main")
-                self.default_values()
+            self.base_config_path = os.environ['HOME'] + "/.config/gbirthday"
+            if not os.path.isdir(self.base_config_path):
+                os.makedirs(self.base_config_path)
+
+        # If no config in base path, check old path ~/.gbirthdayrc
+        # This is here for backward compatibility, remove it when time has come
+        if not os.path.exists(self.base_config_path + '/gbirthdayrc'):
+            if os.path.exists(os.environ['HOME'] + '/.gbirthdayrc'):
+                shutil.copy2(os.environ['HOME'] + '/.gbirthdayrc',
+                             self.base_config_path + '/gbirthdayrc')
+
+        # If XDG_DATA_HOME is defined, use it to store data files
+        if 'XDG_DATA_HOME' in os.environ:
+            self.base_data_path = os.environ['XDG_DATA_HOME'] + "/gbirthday"
+        # else, use ~/.local/share
+        else:
+            self.base_data_path = os.environ['HOME'] + "/.local/share/gbirthday"
+
+        try:
+            self.settings.readfp(file(self.base_config_path + '/gbirthdayrc'))
+        except IOError:
+            pass
+        
+        self.sync_to_mem()
 
         self.correct_settings()
 
@@ -91,7 +119,7 @@ class Conf:
         '''correct new settings, e.g. Evolution and not evolution anymore'''
         def replace(old, new, changed):
             '''replace old with new'''
-            for num in range(len(self.used_databases)):
+            for num, item in enumerate(self.used_databases):
                 if self.used_databases[num] == old:
                     changed = True
                     self.used_databases[num] = new
@@ -106,35 +134,45 @@ class Conf:
         if changed:
             self.save()
 
-    def default_values(self):
-        '''Initialize with default values.'''
-        self.firstday = -2
-        self.lastday = 30
-        self.notify_future_bdays = 0
-        self.used_databases = ['Evolution']
-        self.csv_files = None
-
     def sync_to_mem(self):
         '''Get current settings from config parser into this object.'''
-        import ConfigParser
 
-        self.firstday = int(self.settings.get("main", "firstday"))
-        self.lastday = int(self.settings.get("main", "lastday"))
-        used_db = self.settings.get("main", "databases")
-        self.used_databases = used_db.split("|")
-        try:
-            self.notify_future_bdays = self.settings.get("main",
-                        "notify_future_bdays")
-            self.notify_future_bdays = int(self.notify_future_bdays)
-        except ConfigParser.NoOptionError:
-            self.notify_future_bdays = 0
-        try:
-            self.csv_files = eval(self.settings.get("main", "csv_files"))
+        def get_setting_value(section, value, default):
+            '''Get setting value. If not found, return default'''
+            try:
+                return self.settings.get(section, value)
+            except (ConfigParser.NoOptionError, \
+                    ConfigParser.NoSectionError):
+                return default
 
+        self.firstday = int(get_setting_value("main", "firstday", -2))
+        self.lastday = int(get_setting_value("main", "lastday", 30))
+        used_db = get_setting_value("main", "databases", "")
+        if used_db != "":
+            self.used_databases = used_db.split("|")
+        else:
+            self.used_databases = []
+        self.notify_future_bdays = int(get_setting_value("main",
+                                       "notify_future_bdays", 0))
+        
+        self.csv_files = eval(get_setting_value("main", "csv_files", 'None'))
+        
+        self.ics_export = eval(get_setting_value("ics_export", "export",
+                                                 'False'))
+        self.ics_filepath = get_setting_value("ics_export", "filepath",
+                                        self.base_data_path + '/gbirthday.ics')
+        self.ics_custom_properties = get_setting_value("ics_export",
+                                                "custom_properties", '')
+        self.ics_alarm = eval(get_setting_value("ics_export", "alarm", 'False'))
+        self.ics_alarm_days = get_setting_value("ics_export", "alarm_days", '5')
+        self.ics_alarm_custom_properties = get_setting_value("ics_export",
+                                                "alarm_custom_properties", '')
+
+        try:
             self.mysql.host = self.settings.get("mysql", "host")
             self.mysql.port = self.settings.get("mysql", "port")
             self.mysql.username = self.settings.get("mysql", "username")
-            self.mysql.passwort = self.settings.get("mysql", "password")
+            self.mysql.password = self.settings.get("mysql", "password")
             self.mysql.database = self.settings.get("mysql", "database")
             self.mysql.table = self.settings.get("mysql", "table")
             self.mysql.name_row = self.settings.get("mysql", "name_row")
@@ -144,6 +182,9 @@ class Conf:
 
     def sync_to_settings(self):
         '''Save current settings from this object to config parser.'''
+        # main
+        if not self.settings.has_section("main"):
+            self.settings.add_section("main")
         self.settings.set("main", "firstday", self.firstday)
         self.settings.set("main", "lastday", self.lastday)
         self.settings.set("main", "notify_future_bdays",
@@ -152,9 +193,11 @@ class Conf:
         for database in self.used_databases:
             used_db += database
             used_db += "|"
-        # db[:-1] because of removing the latest "|"
+        # db[:-1] because of removing the last "|"
         self.settings.set("main", "databases", used_db[:-1])
         self.settings.set("main", "csv_files", self.csv_files)
+        
+        # mysql
         if self.mysql:
             if not self.settings.has_section("mysql"):
                 self.settings.add_section("mysql")
@@ -167,16 +210,27 @@ class Conf:
             self.settings.set("mysql", "name_row", self.mysql.name_row)
             self.settings.set("mysql", "date_row", self.mysql.date_row)
 
+        # ics_export
+        if not self.settings.has_section("ics_export"):
+            self.settings.add_section("ics_export")
+        self.settings.set("ics_export", "export", self.ics_export)
+        self.settings.set("ics_export", "filepath", self.ics_filepath)
+        self.settings.set("ics_export", "custom_properties",
+                            self.ics_custom_properties)
+        self.settings.set("ics_export", "alarm", self.ics_alarm)
+        self.settings.set("ics_export", "alarm_days", self.ics_alarm_days)
+        self.settings.set("ics_export", "alarm_custom_properties", 
+                            self.ics_alarm_custom_properties)
+    
     def save(self):
         '''Save current settings to disk.'''
         self.sync_to_settings()
-        self.settings.write(file(os.environ['HOME'] + "/.gbirthdayrc", "w"))
-
+        self.settings.write(file(self.base_config_path + '/gbirthdayrc', "w"))
 
 def main():
     '''Load settings, start status icon and get to work.'''
-    from .addressbook import AddressBook
-    from .status_icon import StatusIcon
+    from addressbook import AddressBook
+    from status_icon import StatusIcon
     # try to load settings
     conf = Conf()
 
